@@ -93,7 +93,7 @@ class CLI(cl1.CLI):
 	def start(self):
 		
 		# check arguments.
-		self.arguments.check(json=JSON)
+		self.arguments.check(json=JSON, exceptions=["--log-level", "--version", "--create-alias", "--non-interative"])
 
 		#
 		# BASICS
@@ -125,11 +125,36 @@ class CLI(cl1.CLI):
 		elif self.arguments.present('--reset-cache'):
 			path = f"{HOME}/.{ALIAS}/.cache/"
 			os.system(f"rm -fr {path}")
-			if os.path.exists(path):
+			if Files.exists(path):
 				self.stop(error=f"Failed to reset cache {path}.", json=JSON)
 			else:
 				self.stop(message=f"Successfully resetted cache {path}.", json=JSON)
 
+
+		#
+		# SESSIONS
+		#
+
+		# start session.
+		elif self.arguments.present("--session"):
+			alias = self.arguments.get("--session", chapter="sessions", mode="--session")
+			response = ssht00ls.ssh.session(alias=alias)
+			sys.exit(0)
+			#self.stop(response=response)
+
+		# command.
+		elif self.arguments.present("--command"):
+			alias = self.arguments.get("--command", chapter="sessions", mode="--command")
+			command = self.arguments.get("--command", chapter="sessions", mode="--command", index=2)
+			response = ssht00ls.ssh.command(
+				alias=alias,
+				command=command,
+				serialize=JSON,)
+			if not response.success:
+				self.stop(response=response)
+			else:
+				sys.exit(0)
+
 		#
 		# ALIASES
 		#
@@ -217,7 +242,7 @@ class CLI(cl1.CLI):
 							alias=alias,
 							# the edits (dict).
 							edits={
-								"user":self.arguments.get("--username", required=False, default=None),
+								"username":self.arguments.get("--username", required=False, default=None),
 								"public_ip":self.arguments.get("--public_ip", required=False, default=None),
 								"public_port":self.arguments.get("--public_port", required=False, default=None),
 								"private_ip":self.arguments.get("--private_ip", required=False, default=None),
