@@ -281,6 +281,14 @@ class Aliases(object):
 		for alias in list(CONFIG["aliases"].keys()):
 			info = CONFIG["aliases"][alias]
 			if "example.com " not in alias:
+				# deprications.
+				if "user" in info:
+					user = info["user"]
+					del info["user"]
+					info["username"] = user
+					CONFIG["aliases"][alias]["user"] = user
+					utils.save_config_safely()
+				# proceed.
 				checked = Dictionary(path=False, dictionary=info).check(default={
 					"username":None,
 					"public_ip":None,
