@@ -77,7 +77,7 @@ cache = syst3m.cache.Cache(
 
 # files.
 DATABASE = Files.Directory(path=f"{HOME}/.{ALIAS}")
-CONFIG = Dictionary(path=syst3m.env.fill(syst3m.env.get_string("SSHT00LS_CONFIG", default=DATABASE.join("config",""))), load=True)
+CONFIG = Dictionary(path=syst3m.env.fill(syst3m.env.get_string("SSHT00LS_CONFIG", default=DATABASE.join("config",""))), load=True, default={})
 
 # netw0rk settings.
 IPINFO_API_KEY = os.environ.get("IPINFO_API_KEY")
@@ -91,7 +91,7 @@ DEFAULT_SSH_OPTIONS = f"-o ConnectTimeout={SSH_TIMEOUT} -o ConnectionAttempts={S
 SSYNC_DAEMON_SLEEPTIME = round(float(cl1.get_argument("--daemon-sleeptime", required=False, default=0.25)), 2)
 
 # speed up non interactive.
-if CHECKS:
+if CHECKS and not cl1.arguments_present("--reset-cache"):
 
 	# network.
 	NETWORK_INFO = netw0rk.network.info()
