@@ -23,7 +23,7 @@ class Connections(object):
 						"sendq":sendq,
 						"net_id":net_id,
 					}
-		return r3sponse.success_response(f"Successfully listed {len(connections)} ssh connection(s).", {
+		return r3sponse.success(f"Successfully listed {len(connections)} ssh connection(s).", {
 			"connections":connections,
 		})
 
