@@ -49,7 +49,7 @@ class SCP(object):
 			if not response["success"]: return response
 
 		# check client path.
-		if os.path.exists(client_path):
+		if Files.exists(client_path):
 			response["error"] = f"Client path [{client_path}] already exists."
 			return response
 
@@ -71,7 +71,7 @@ class SCP(object):
 			response["error"] = f"Server path [{server_path}] is a directory."
 			return response
 		elif "" == output:
-			if not os.path.exists(client_path):
+			if not Files.exists(client_path):
 				response["error"] = f"Failed to download [{server_path}]."
 				return response
 			# check success.	
@@ -121,7 +121,7 @@ class SCP(object):
 			if not response["success"]: return response
 
 		# check client path.
-		if not os.path.exists(client_path):
+		if not Files.exists(client_path):
 			response["error"] = f"Client path [{client_path}] does not exist."
 			return response
 
