@@ -273,12 +273,12 @@ class SSHD(object):
 		os.system(f"rm -fr {path}")
 		os.system(f"rm -fr /tmp/ssht00ls/")
 		os.system(f'git clone https://github.com/vandenberghinc/ssht00ls /tmp/ssht00ls/')
-		if not os.path.exists(f"/tmp/ssht00ls/"):
+		if not Files.exists(f"/tmp/ssht00ls/"):
 			return r3sponse.error("Failed to install the ssht00ls utils. #1")
 		os.system(f"mv /tmp/ssht00ls/ssht00ls/classes/utils/ {path}")
 		os.system(f"rm -fr {path}/__pycache__")
 		os.system(f"rm -fr {path}/__init__.py")
-		if not os.path.exists(path):
+		if not Files.exists(path):
 			return r3sponse.error("Failed to install the ssht00ls utils. #2")
 
 		# iterate.
