@@ -17,7 +17,7 @@ class SSync(object):
 		self.daemons = daemons
 		if CHECKS and INTERACTIVE:
 			response = aliases.sync()
-			if not response["success"]: response.crash(traceback=False, json=JSON)
+			if not response["success"]: response.crash(json=JSON)
 			if not cl1.argument_present("--reset-cache"):
 				_ = daemons.sync()
 	def mount(self, 
@@ -75,7 +75,7 @@ class SSync(object):
 		else:
 			# make sure both dirs exist in the end.
 			# raise error when both dirs do not exist at start.
-			response = ssh.utils.test_ssh_dir(path=remote, alias=alias)
+			response = ssh.utils.test_dir(path=remote, alias=alias)
 			remote_exists, local_exists = True, Files.exists(path)
 			if not response["success"]: 
 				if "does not exist" in response["error"]:
@@ -89,7 +89,7 @@ class SSync(object):
 				if not Files.exists(path): 
 					return r3sponse.error(f"Failed to create directory {path}.")
 			if not remote_exists:
-				response = ssh.utils.test_ssh_dir(path=remote, alias=alias, create=True)
+				response = ssh.utils.test_dir(path=remote, alias=alias, create=True)
 				if not response["success"]: 
 					return r3sponse.error(f"Failed to create directory {alias}:{remote}, error: {response['error']}")
 
@@ -174,7 +174,7 @@ class SSync(object):
 				if not response["success"]: return response
 				response = ssh.utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
 				if not response["success"]: return response
-				response = ssh.utils.test_ssh_path(alias=alias, path=path, accept_new_host_keys=accept_new_host_keys)
+				response = ssh.utils.test_path(alias=alias, path=path, accept_new_host_keys=accept_new_host_keys)
 				if not response["success"]: return response
 
 			# index.
